@@ -437,7 +437,7 @@ FlashGotDM.prototype = {
     if (fg.getPref("omitCookies")) return null;
     
     const cookies = [];
-    this.cookieExpires = new Date().getTime() + 24 * 3600 * 3650; // ten years for session cookies
+    this.cookieExpires = Date.now() + 24 * 3600 * 3650; // ten years for session cookies
     
     for (var cookie, iter = fg.cookieManager.enumerator; iter.hasMoreElements();) {
       if ((cookie = iter.getNext()) instanceof CI.nsICookie) {
@@ -1351,6 +1351,10 @@ FlashGotDM.initDMS = function() {
   for each (dm in [new FlashGotDM("DTA"), new FlashGotDM("DTA (Turbo)")]) {
     dm.__defineGetter__("supported", 
       function() {
+        try {
+          IOS.newChannel("chrome://dta-modules/content/support/filtermanager.js", null, null);
+          return true;
+        } catch(e) {}
         try {
           IOS.newChannel("resource://dta/support/filtermanager.jsm", null, null);
           return true;
@@ -1374,7 +1378,13 @@ FlashGotDM.initDMS = function() {
       try {
         if (!("DTA" in this)) {
           this.DTA = {};
-          Components.utils.import("resource://dta/api.jsm", this.DTA);
+          try {
+            Components.utils.import("resource://dta/api.jsm", this.DTA);
+          } catch (e) {
+            var glue = {}
+            Components.utils.import("chrome://dta-modules/content/glue.jsm", glue);
+            this.DTA = glue.require("api");
+          }
         }
         DTA = this.DTA;
         wrapURL = function(url, cs) { return new DTA.URL(IOS.newURI(url, cs, null)); }
