@@ -39,12 +39,16 @@ var DOM = {
       return null;
     }
   },
-  updateStyleSheet: function(sheet, enabled) {
-    
+  
+  get styleSheetService() {
+    delete this.styleSheetService;
     const sssClass = CC["@mozilla.org/content/style-sheet-service;1"];
-    if (!sssClass) return;
-      
-    const sss = sssClass.getService(CI.nsIStyleSheetService);
+    return this.styleSheetService = sssClass && sssClass.getService(CI.nsIStyleSheetService);     
+  },
+  updateStyleSheet: function(sheet, enabled) {
+    const sss = this.styleSheetService;
+    if (!sss) return;
+    
     const uri = IOS.newURI("data:text/css," + sheet, null, null);
     if (sss.sheetRegistered(uri, sss.USER_SHEET)) {
       if (!enabled) sss.unregisterSheet(uri, sss.USER_SHEET);
