@@ -93,11 +93,11 @@ var MediaSniffer = {
     return m && { fname: m[1], contentType: contentType };
   },
   
-  typesWhitelistRx: /\b(?:x?html|image|css|j(?:ava(?:script)?|son)|shockwave)\b/i,
+  typesWhitelistRx: /\b(?:x(?:ht)?ml|image|css|j(?:ava(?:script)?|son)|shockwave)\b/i,
   
   get downloadInterface() {
     delete this.downloadInterface;
-    return this.downloadInterface = "nsIHttpActivityObserver" in CI ? CI.nsIProgressEventSink : CI.nsIWebBrowserPersist;
+    return this.downloadInterface = "nsIHttpActivityObserver" in CI ? CI.nsICancelable : CI.nsIWebBrowserPersist;
   },
   
   observe: function(channel, topic, data) {
