@@ -914,7 +914,7 @@ RedirectContext.prototype = {
             // renew captcha
             ee = renew.getElementsByTagName("img");
              for(j = ee.length; j-- > 0;) 
-               ee[j].src = ee[j].src + "?" + new Date().getTime();
+               ee[j].src = ee[j].src + "?" + Date.now();
           }
           
           context.links.splice(context.links.indexOf(l), 1); 
