@@ -1,7 +1,7 @@
 /***** BEGIN LICENSE BLOCK *****
 
     FlashGot - a Firefox extension for external download managers integration
-    Copyright (C) 2004-2009 Giorgio Maone - g.maone@informaction.com
+    Copyright (C) 2004-2011 Giorgio Maone - g.maone@informaction.com
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,28 +19,14 @@
                              
 ***** END LICENSE BLOCK *****/
 
-var gFlashGotService = (function() {
-  var fg = null;
-  for(var attempt = 1; attempt <= 2; attempt++) {
-    try {
-     fg = Components.classes["@maone.net/flashgot-service;1"].getService(Components.interfaces.nsISupports).wrappedJSObject;
-     if(attempt == 2 && fg.dirtyJobs) fg.dirtyJobs();
-     break;
-    } catch(ex) {
-      dump(ex.message);
-      window.navigator.plugins.refresh();
-    }
-  }
-  fg.init();
-  return fg;
-})();
-
+var gFlashGotService = Components.classes["@maone.net/flashgot-service;1"].getService().wrappedJSObject;
+   
 var flashgotUtil = {
   browse: function(url, feature) {
     var w = gFlashGotService.dom.mostRecentBrowserWindow;
     if(w && !w.closed) {
       var browser = w.getBrowser();
-      browser.selectedTab = browser.addTab(url, null);
+      browser.selectedTab = browser.addTab(url);
     } else {
       window.open(url, "_blank", features || null)
     }
