@@ -1,7 +1,7 @@
 /***** BEGIN LICENSE BLOCK *****
 
     FlashGot - a Firefox extension for external download managers integration
-    Copyright (C) 2004-2009 Giorgio Maone - g.maone@informaction.com
+    Copyright (C) 2004-2011 Giorgio Maone - g.maone@informaction.com
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -280,7 +280,7 @@ FlashGotGalleryBuilder.prototype = {
       var html = htmlBuilder.header; 
       os.write(html, html.length);
       
-      while(html=htmlBuilder.nextFragment() ) {
+      while( (html = htmlBuilder.nextFragment()) ) {
         os.write(html, html.length);
         if(!htmlBuilder.valid) break;
       }
@@ -291,18 +291,17 @@ FlashGotGalleryBuilder.prototype = {
     } finally {
       os.close();
     }
-    const ios=cc['@mozilla.org/network/io-service;1'].getService(ci.nsIIOService);
     
-    var w=this.originalWindow;
-    var url=ios.newFileURI(galFile).spec;
+    var w = this.originalWindow;
+    var url = Components.classes["@mozilla.org/network/io-service;1"].getService(Components.interfaces.nsIIOService).newFileURI(galFile).spec;
     if(typeof(w.messenger)=="object" && w.messenger.OpenURL) { 
       // Thunderbird
       w.messenger.OpenURL(url);
     } else if(w.closed) {
-      w = window.open(url,"_blank");
+      w = window.open(url, "_blank");
     } else {
       var browser = w.getBrowser();
-      browser.selectedTab = browser.addTab(url, null);
+      browser.selectedTab = browser.addTab(url);
     }
   }
 ,
@@ -486,29 +485,30 @@ FlashGotGalleryHTML.prototype = {
   }
 ,
   // evaluates macros and javascript functions
-  _macroPattern: /\[\$(0*\d)\]/g,
+  _macroPattern: /\[\$(\d+)\]/g,
   evalExpressions: function(iterator) {
-    var url=iterator.nextURL();
-    if(!url) return url;
-    const index=this.index;
+    var url = iterator.nextURL();
+    if (!url) return url;
+    const index = this.index;
     
     // macro evaluation
-    url=url.replace(this._macroPattern,function(all,digits) {
-      var n=parseInt(digits);
-      const len=digits.length;
+    url = url.replace(this._macroPattern, function(all, digits) {
+      var n = parseInt(digits);
+      const len = digits.length;
       var res;
-      if(n==0) {
-         res=index.toString();
+      if (n == 0) {
+         res = index.toString();
       } else {
-        var delegate=iterator;
-        while(n-->1 && delegate) delegate=delegate.delegate;
-        if(!delegate) return all;
-        res=delegate.renderedCursor;
-        if(len>0) res=res.toString().replace(/^[0]+/,"");
+        var delegate = iterator;
+        while (n-- > 1 && delegate) delegate = delegate.delegate;
+        if (!delegate) return all;
+        res = delegate.renderedCursor;
+        if (len > 0) res = res.toString().replace(/^0+/, "");
       }
       
-      return len>0?
-        digits.substring(0,digits.length-res.length).concat(res):res;
+      return len > 0
+        ? digits.replace(/\d/g, '0').substring(0, len - res.length).concat(res)
+        : res;
     });
     
     if(!(this.exprNames.length && this.env))  return url;
@@ -594,35 +594,34 @@ function FlashGotGalleryIterator(base) {
   var match=FlashGotGalleryBuilder.INTERVAL_RX.exec(this.base);
   var matchAZ=FlashGotGalleryBuilder.INTERVAL_AZ_RX.exec(this.base);
   if(match && ( (!matchAZ) || matchAZ.index>match.index) ) {
-    var idx=match.index;
-    this.isAZ=false;
-    this.start=parseInt(match[1],10);
-    this.end=parseInt(match[2],10);
-    this.padding="";
+    var idx = match.index;
+    this.isAZ = false;
+    this.start = parseInt(match[1],10);
+    this.end = parseInt(match[2],10);
+    this.padding = "";
     for(var j=(this.end>this.start?match[1]:match[2]).length; 
       j-->0; 
       this.padding=this.padding.concat("0") 
       );
     this.valid=true;
-  } else if(this.isAZ=((match=matchAZ)!=null)) {
+  } else if((this.isAZ=((match=matchAZ)!=null))) {
     if(/[a-z]{1}/.test(match[1])) {
-      match[2]=match[2].toLowerCase();
+      match[2] = match[2].toLowerCase();
     } else {
-      match[2]=match[2].toUpperCase();
+      match[2] = match[2].toUpperCase();
     }
-    this.start=match[1].charCodeAt(0);
-    this.end=match[2].charCodeAt(0);  
-    this.valid=true;
+    this.start = match[1].charCodeAt(0);
+    this.end = match[2].charCodeAt(0);  
+    this.valid = true;
   } else {
-    this.valid=false;
+    this.valid = false;
     return;
   }
   
-  this.match=match;
+  this.match = match;
   
-  var stepMatch=this.match[3].match(/;\s*(\d+)/);
-  this.step =  (stepMatch?parseInt(stepMatch[1],10):1
-    ) * (this.start<=this.end?1:-1);
+  var stepMatch = this.match[3].match(/;\s*(\d+)/);
+  this.step =  (stepMatch ? parseInt(stepMatch[1], 10) : 1) * (this.start <= this.end ? 1 : -1);
     
   this.cursor=this.start;
  
