@@ -59,14 +59,45 @@ var gFlashGot = {
     
     target.addEventListener("mousedown", function(ev) {
       if (!(ev.button <= 1 && gFlashGot._isContentEvent(ev))) return;
-      gFlashGot.mouseDown = { x: ev.screenX, y: ev.screenY };
+      if (gFlashGot.mouseDown && gFlashGot.mouseDown.gesture === 1)
+        gFlashGotService.cursor(false);
+      
+      gFlashGot.mouseDown = {
+        x: ev.screenX,
+        y: ev.screenY,
+        gesture: ev.button === 1 ? 0 : -1,
+        lastY: ev.screenY
+      };
       gFlashGot.hoverElement = ev.originalTarget;
     }, false);
     
     target.addEventListener("mousemove", function(ev) {
       const md = gFlashGot.mouseDown;
-      if (md && md.y && ev.screenY < md.y) {
-        md.y = 0;
+      if (!md) return;
+      
+      switch(md.gesture) {
+        case -1: // aborted
+          return;
+        case 0: // yet to be started
+          if (Math.sqrt(Math.pow(ev.screenX - md.x, 2) + Math.pow(ev.screenY - md.y, 2)) < 12)
+            break; // too near
+          if (gFlashGot.isSelInvalid && !gFlashGot.currentLink) {
+            md.gesture = -1;
+            break;
+          }
+        case 1: // ongoing gesture
+          var sy = ev.screenY;
+          var dy = sy - md.lastY;
+          md.lastY = sy;
+          if (dy < 0 || Math.abs(ev.screenX - md.x) / (ev.screenY - md.y) > .25 ||
+              !gFlashGot._isContentEvent(ev)) {
+            // raising back or not south, abort
+            if (md.gesture === 1) gFlashGotService.cursor(false);
+            md.gesture = -1;
+          } else if (md.gesture === 0) {
+            md.gesture = 1;
+            if (gFlashGotService.getPref("gesture.feedback")) gFlashGotService.cursor(true);
+          }
       }
     }, false);
     
@@ -87,6 +118,11 @@ var gFlashGot = {
       const button = ev.button;
       gFlashGot.mouseDown = null;
       
+      var gesture = md && md.gesture === 1;
+      if (gesture) {
+        gFlashGotService.cursor(false);
+      }
+      
       if (!(button <= 1 && gFlashGot._isContentEvent(ev) && gFlashGotService.interceptor)
           || ev.ctrlKey || ev.metaKey)
         return;
@@ -94,20 +130,11 @@ var gFlashGot = {
       gFlashGotService.interceptor.bypassAutoStart = false;
       gFlashGotService.interceptor.forceAutoStart = false;
       
-      var trigger = false;
-      if (button === 0) {
-        trigger = ev.altKey;
-      } else if (md.y) {
-        var dy = ev.screenY - md.y;
-        var dx = Math.abs(ev.screenX - md.x);
-        trigger = dy > 16 && dx < 16 && dx / dy < .5; // south gesture
-      }
-      
-      if(trigger) {
+      if (gesture || button === 0 && ev.altKey) {
         function prevent() {
           ev.preventDefault();
           ev.stopPropagation();
-          gFlashGot.lastClickCaptureTime = new Date().getTime();
+          gFlashGot.lastClickCaptureTime = Date.now();
         }
         
         if (button === 0) {
@@ -147,7 +174,7 @@ var gFlashGot = {
     target.addEventListener("click", function(ev) {
       if(ev.altKey && ev.originalTarget.ownerDocument != document &&
         typeof(gFlashGot.lastClickCaptureTime) == "number" && 
-        new Date().getTime() - gFlashGot.lastClickCaptureTime < 100
+        Date.now() - gFlashGot.lastClickCaptureTime < 100
       ) {
         ev.preventDefault();
         ev.stopPropagation();
@@ -494,7 +521,8 @@ var gFlashGot = {
       if (el) el.parentNode.removeChild(el);
       widgetId = "flashgot-media-tbb";
       el = document.getElementById(widgetId);
-      if (el && el.nextSibling && el.nextSibling.id == "search-container") {
+      if (el && (el.nextSibling && el.nextSibling.id == "search-container" ||
+                 addonBar.collapsed && el.parentNode == addonBar)) {
         el = null;
       }
       if (!el) {
@@ -657,6 +685,12 @@ var gFlashGot = {
   get popupLink() { 
     return this.findLinkAsc(document.popupNode);
   }
+,
+  get currentLink() { 
+    const sel = this.srcWindow.getSelection();
+    return !sel.isCollapsed && this._wrapAnchor(sel.anchorNode)
+      || this.findLinkAsc(this.hoverElement) || this.findLinkAsc(document.commandDispatcher.focusedElement);
+  }
 ,
   get linksCount() {
     const doc = this.srcDocument;
@@ -916,15 +950,13 @@ var gFlashGot = {
   }
 ,
   downloadLink: function(dmName) {
-    const sel = this.srcWindow.getSelection();
-    var link = !sel.isCollapsed && this._wrapAnchor(sel.anchorNode)
-      || this.findLinkAsc(this.hoverElement) || this.findLinkAsc(document.commandDispatcher.focusedElement);
+    const link = this.currentLink;
     return link && this.download([link], gFlashGotService.OP_ONE, dmName);
   }
 ,
   downloadSel: function(dmName) {
     if(this.isSelInvalid) return false;
-    const startTime = new Date().getTime();
+    const startTime = Date.now();
     const links = this.getSelectionLinks(gFlashGotService.getPref("includeImages"));
     if(!links.length) return false;
     links.startTime = startTime;
@@ -957,7 +989,7 @@ var gFlashGot = {
   }
 ,
   get media() {
-    return "_flashgotMedia" in content ? content._flashgotMedia : null;
+    return gFlashGotService.getMedia(content);
   },
   
   addMediaLinks: function(links, mm) {
@@ -977,7 +1009,7 @@ var gFlashGot = {
   }
 ,
   downloadAll: function(dmName) {
-    const startTime = new Date().getTime();
+    const startTime = Date.now();
     const links = this.collectAllLinks(content.document);
     links.startTime = startTime;
     return this.download(links, gFlashGotService.OP_ALL, dmName);
@@ -1038,8 +1070,8 @@ var gFlashGot = {
   },
   
   showProgressValue: function(v) {
-    document.getElementById("flashgot-progresspanel").setAttribute("collapsed",
-        v < 100 ? "false" : "true");
+    var done = v >= 100; 
+    document.getElementById("flashgot-progresspanel").collapsed = done;
     document.getElementById("flashgot-progressmeter").value = v;
     gFlashGotService.yield();
   },
