@@ -28,7 +28,7 @@ const NS_BINDING_ABORTED = 0x804b0002;
 const EXTENSION_ID = "{19503e42-ca3c-4c27-b1e2-9cdb2170ee34}";
 const EXTENSION_NAME = "FlashGot";
 const CHROME_NAME = "flashgot";
-const VERSION = "1.4";
+const VERSION = "1.4.5";
 const SERVICE_NAME = EXTENSION_NAME + " Service";
 const SERVICE_CTRID = "@maone.net/flashgot-service;1";
 const SERVICE_ID = "{2a55fc5c-7b31-4ee1-ab15-5ee2eb428cbe}";
@@ -371,6 +371,11 @@ fg = {
      }
      document._FlashGot_NativeUI_styleSheets = null;
   },
+  
+  cursor: function(b) {
+    DOM.updateStyleSheet('@-moz-document regexp("https?:.*") { body * { cursor: url(chrome://flashgot/skin/icon32.png), auto !important }}', b);
+  },
+  
   _httpServer: null,
   get httpServer() {
     if (typeof(FlashGotHttpServer) != "function") {
@@ -1246,6 +1251,10 @@ fg = {
 ,
   showDMSReference: function() {
     this.getWindow().open("http://flashgot.net/dms","_blank");
+  },
+  
+  getMedia: function(w) {
+    return "_flashgotMedia" in w ? w._flashgotMedia : null;
   }
 , 
 
@@ -1304,3 +1313,4 @@ fg = {
   }
 }
 
+fg.__global__ = this;
